@@ -44,15 +44,47 @@ module Rabl
 
       wrap_result(options[:root_name])
 
-      replace_nil_values if Rabl.configuration.replace_nil_values_with_empty_strings
+      replace_nil_values          if Rabl.configuration.replace_nil_values_with_empty_strings
+      replace_empty_string_values if Rabl.configuration.replace_empty_string_values_with_nil_values
+      remove_nil_values           if Rabl.configuration.exclude_nil_values
 
       # Return Results
       @_root_name ? { @_root_name => @_result } : @_result
     end
 
     def replace_nil_values
+      @_result = deep_replace_nil_values(@_result)
+    end
+
+    def deep_replace_nil_values(hash)
+      hash.inject({}) do |hsh, (k, v)|
+        hsh[k] = if v.is_a?(Hash)
+          deep_replace_nil_values(v)
+        else
+          v.nil? ? '' : v
+        end
+        hsh
+      end
+    end
+
+    def replace_empty_string_values
+      @_result = deep_replace_empty_string_values(@_result)
+    end
+
+    def deep_replace_empty_string_values(hash)
+      hash.inject({}) do |hsh, (k, v)|
+        hsh[k] = if v.is_a?(Hash)
+          deep_replace_empty_string_values(v)
+        else
+          (!v.nil? && v != "") ? v : nil
+        end
+        hsh
+      end
+    end
+
+    def remove_nil_values
       @_result = @_result.inject({}) do |hash, (k, v)|
-        hash[k] = v.nil? ? '' : v
+        hash[k] = v unless v.nil?
         hash
       end
     end
@@ -83,7 +115,9 @@ module Rabl
     # attribute :foo, :as => "bar", :if => lambda { |m| m.foo }
     def attribute(name, options={})
       if @_object && attribute_present?(name) && resolve_condition(options)
-        @_result[options[:as] || name] = data_object_attribute(name)
+        attribute = data_object_attribute(name)
+        name = (options[:as] || name).to_sym
+        @_result[name] = attribute
       end
     end
     alias_method :attributes, :attribute
@@ -95,7 +129,7 @@ module Rabl
       return unless resolve_condition(options)
       result = block.call(@_object)
       if name.present?
-        @_result[name] = result
+        @_result[name.to_sym] = result
       elsif result.respond_to?(:each_pair) # merge hash into root hash
         @_result.merge!(result)
       end
@@ -114,7 +148,7 @@ module Rabl
       engine_options = @options.slice(:child_root).merge(:root => include_root)
       engine_options.merge!(:object_root_name => options[:object_root]) if is_name_value?(options[:object_root])
       object = { object => name } if data.respond_to?(:each_pair) && object # child :users => :people
-      @_result[name] = self.object_to_hash(object, engine_options, &block)
+      @_result[name.to_sym] = self.object_to_hash(object, engine_options, &block)
     end
 
     # Glues data from a child node to the json_output
