@@ -1,6 +1,7 @@
 module Rabl
   class Engine
     include Rabl::Partials
+    include Rabl::Helpers::Escaper
 
     # List of supported rendering formats
     FORMATS = [:json, :xml, :plist, :bson, :msgpack]
@@ -35,12 +36,12 @@ module Rabl
       options[:root_name] = determine_object_root(data, root_name, options[:root])
 
       if is_object?(data) || !data # object @user
-        builder.build(data, options)
+        result = builder.build(data, options)
       elsif is_collection?(data) # collection @users
         result = data.map { |object| builder.build(object, options) }
         result = result.map(&:presence).compact if Rabl.configuration.exclude_empty_values_in_collections
-        result
       end
+      Rabl.configuration.escape_all_output ? escape_output(result) : result
     end
 
     # Returns a json representation of the data object
@@ -109,6 +110,10 @@ module Rabl
       current_data  = (@_locals[:object].nil? || template_data == false) ? template_data : @_locals[:object]
       @_data_object = data_object(current_data)
       @_data_name   = data_name(template_data.is_a?(Hash) && !current_data.is_a?(Hash) ? template_data : current_data)
+      if @_data_name == false
+        @_object_root_name = false
+        @_collection_name = false
+      end
     end
 
     # Returns the current object that is the topic of this template
@@ -277,10 +282,10 @@ module Rabl
       _cache = @_cache if defined?(@_cache)
       cache_key, cache_options = *_cache || nil
       if template_cache_configured? && cache_key
-        if Rails.version =~ /^[4]/
-          result_cache_key = cache_key_with_digest(cache_key)
-        else # fallback for Rails 3
-          result_cache_key = cache_key_simple(cache_key)
+        result_cache_key = if digestor_available?
+          cache_key_with_digest(cache_key)
+        else # fallback for Rails 3, and Non-Rails app
+          cache_key_simple(cache_key)
         end
         fetch_result_from_cache(result_cache_key, cache_options, &block)
       else # skip caching
@@ -288,11 +293,15 @@ module Rabl
       end
     end
 
+    def digestor_available?
+      defined?(Rails) && Rails.version =~ /^[4]/
+    end
+
     def cache_key_with_digest(cache_key)
       template = @_options[:template] || @virtual_path
 
-      if Rails.version.to_s >= '4.1'
-        digested =  Digestor.digest(name: template, finder: lookup_context)
+      if Gem::Version.new(Rails.version) >= Gem::Version.new('4.1')
+        digested =  Digestor.digest(:name => template, :finder => lookup_context)
       else
         digested = Digestor.digest(template, :rabl, lookup_context)
       end
