@@ -46,15 +46,57 @@ context "Rabl::Builder" do
     context "when nil values are replaced with empty strings" do
       setup do
         Rabl.configuration.replace_nil_values_with_empty_strings = true
-        builder({ :attributes => { :name => {} } })
+        builder({ :attributes => { :name => {} }, :node => [{ :name => :extra, :options => {}, :block => lambda { |u| { :twitter => u.twitter } } }] })
       end
+
       asserts "that an empty string is returned as the value" do
-        topic.build(User.new(:name => nil))
-      end.equivalent_to({ :name => "" })
+        topic.build(User.new(:name => nil, :twitter => nil))
+      end.equivalent_to({ :name => '', :extra => { :twitter => '' } })
+
+      asserts "that it handles existing non nil values correctly" do
+        topic.build(User.new(:name => 10, :twitter => 'twitter'))
+      end.equivalent_to({ :name => 10, :extra => { :twitter => 'twitter' } })
+
       teardown do
         Rabl.configuration.replace_nil_values_with_empty_strings = false
       end
     end
+
+    context "when empty string values are replaced with nil values" do
+      setup do
+        Rabl.configuration.replace_empty_string_values_with_nil_values = true
+        builder({ :attributes => { :name => {} }, :node => [{ :name => :extra, :options => {}, :block => lambda { |u| { :twitter => u.twitter } } }] })
+      end
+
+      asserts "that nil is returned as the value" do
+        topic.build(User.new(:name => "", :twitter => ''))
+      end.equivalent_to({ :name => nil, :extra => { :twitter => nil } })
+
+      asserts "that it handles existing nil values correctly" do
+        topic.build(User.new(:name => nil, :twitter => nil))
+      end.equivalent_to({ :name => nil, :extra => { :twitter => nil } })
+
+      asserts "that it handles existing non nil values correctly" do
+        topic.build(User.new(:name => 10, :twitter => 'twitter'))
+      end.equivalent_to({ :name => 10, :extra => { :twitter => 'twitter' } })
+
+      teardown do
+        Rabl.configuration.replace_empty_string_values_with_nil_values = false
+      end
+    end
+
+    context "when nil values are excluded" do
+      setup do
+        Rabl.configuration.exclude_nil_values = true
+        builder({ :attributes => { :name => {} } })
+      end
+      asserts "that an nil attribute is not returned" do
+        topic.build(User.new(:name => nil))
+      end.equivalent_to({ })
+      teardown do
+        Rabl.configuration.exclude_nil_values = false
+      end
+    end
   end
 
   context "#attribute" do
@@ -79,6 +121,20 @@ context "Rabl::Builder" do
         end.raises(RuntimeError)
       end
     end
+
+    context "that with a string key" do
+      setup { builder({ :attributes => { "name" => {} } }) }
+      asserts "the node name is converted to a symbol" do
+        topic.build(User.new, :name => "user")
+      end.equivalent_to({ :name => "rabl" })
+    end
+
+    context "that with the same node names as strings and symbols" do
+      setup { builder({ :attributes => { "name" => {}, :name => {} } }) }
+      asserts "the nodes aren't duplicated" do
+        topic.build(User.new, :name => "user")
+      end.equivalent_to({ :name => "rabl" })
+    end
   end
 
   context "#node" do
@@ -92,6 +148,17 @@ context "Rabl::Builder" do
         { :name => :baz, :options => {}, :block => lambda { |u| u.city } }
       ]
     end.equivalent_to({:foo => 'bar', :baz => 'irvine'})
+
+    asserts "that it converts the node name to a symbol" do
+      build_hash @user, :node => [{ :name => "foo", :options => {}, :block => lambda { |u| "bar" } }]
+    end.equivalent_to({:foo => 'bar'})
+
+    asserts "that the same node names as a string and symbol aren't duplicated" do
+      build_hash @user, :node => [
+        { :name => "foo", :options => {}, :block => lambda { |u| "bar" } },
+        { :name => :foo, :options => {}, :block => lambda { |u| "bar" } }
+      ]
+    end.equivalent_to({:foo => 'bar'})
   end
 
   context "#child" do
@@ -136,6 +203,19 @@ context "Rabl::Builder" do
       mock(b).object_to_hash(@users, { :root => "person", :object_root_name => "person", :child_root => true }).returns('xyz').subject
       b.build(@user)
     end.equivalent_to({ :people => 'xyz'})
+
+    asserts "that it converts the child name to a symbol" do
+      b = builder(:child => [ { :data => { @user => "user" }, :options => { }, :block => lambda { |u| attribute :name } } ])
+      b.build(@user)
+    end.equivalent_to({ :user => { :name => "rabl" } })
+
+    asserts "that it does't duplicate childs with the same name as a string and symbol" do
+      b = builder(:child => [
+        { :data => { @user => "user" }, :options => { }, :block => lambda { |u| attribute :name } },
+        { :data => { @user => :user }, :options => { }, :block => lambda { |u| attribute :name } }
+      ])
+      b.build(@user)
+    end.equivalent_to({ :user => { :name => "rabl" } })
   end
 
   context "#glue" do
