@@ -1,6 +1,6 @@
 unless defined?(User)
   class User
-    attr_accessor :age, :city, :name, :first, :float, :hobbies
+    attr_accessor :age, :city, :name, :first, :float, :hobbies, :twitter
 
     DEFAULT_AGE      = 24
     DEFAULT_CITY     = 'irvine'
@@ -8,9 +8,10 @@ unless defined?(User)
     DEFAULT_FIRST    = 'bob'
     DEFAULT_FLOAT    = 1234.56
     DEFAULT_HOBBIES  = ['Photography']
+    DEFAULT_TWITTER  = 'rablgem'
 
     def initialize(attributes={})
-      %w(age city name first float hobbies).each do |attr|
+      %w(age city name first float hobbies twitter).each do |attr|
         self.send "#{attr}=", (attributes.has_key?(attr.to_sym) ? attributes[attr.to_sym] : self.class.const_get("DEFAULT_#{attr.upcase}"))
       end
       self.hobbies = self.hobbies.map { |h| Hobby.new(h) }
